==> percona-server-mongodb_4.0.9.orig.tar.gz: percona-server-mongodb-4.0.9-4/src/mongo/db/repl/sync_source_selector_mock.cpp <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/repl/sync_source_selector_mock.h"

namespace mongo {
namespace repl {

SyncSourceSelectorMock::SyncSourceSelectorMock() {}

SyncSourceSelectorMock::~SyncSourceSelectorMock() {}

void SyncSourceSelectorMock::clearSyncSourceBlacklist() {}

HostAndPort SyncSourceSelectorMock::chooseNewSyncSource(const OpTime& ot) {
    _chooseNewSyncSourceHook();
    _chooseNewSyncSourceOpTime = ot;
    return _chooseNewSyncSourceResult;
}

void SyncSourceSelectorMock::blacklistSyncSource(const HostAndPort& host, Date_t until) {
    _lastBlacklistedSyncSource = host;
    _lastBlacklistExpiration = until;
}

void SyncSourceSelectorMock::setChooseNewSyncSourceHook_forTest(
    const ChooseNewSyncSourceHook& hook) {
    _chooseNewSyncSourceHook = hook;
}

bool SyncSourceSelectorMock::shouldChangeSyncSource(
    const HostAndPort&,
    const rpc::ReplSetMetadata&,
    boost::optional<rpc::OplogQueryMetadata> oqMetadata) {
    return false;
}

void SyncSourceSelectorMock::setChooseNewSyncSourceResult_forTest(const HostAndPort& syncSource) {
    _chooseNewSyncSourceResult = syncSource;
}

OpTime SyncSourceSelectorMock::getChooseNewSyncSourceOpTime_forTest() const {
    return _chooseNewSyncSourceOpTime;
}

HostAndPort SyncSourceSelectorMock::getLastBlacklistedSyncSource_forTest() const {
    return _lastBlacklistedSyncSource;
}

Date_t SyncSourceSelectorMock::getLastBlacklistExpiration_forTest() const {
    return _lastBlacklistExpiration;
}

}  // namespace repl
}  // namespace mongo

==> percona-server-mongodb_4.4.16.orig.tar.gz: percona-server-mongodb-4.4.16-16/src/mongo/db/repl/sync_source_selector_mock.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/repl/sync_source_selector_mock.h"

namespace mongo {
namespace repl {

SyncSourceSelectorMock::SyncSourceSelectorMock() {}

SyncSourceSelectorMock::~SyncSourceSelectorMock() {}

void SyncSourceSelectorMock::clearSyncSourceBlacklist() {}

HostAndPort SyncSourceSelectorMock::chooseNewSyncSource(const OpTime& ot) {
    _chooseNewSyncSourceHook();
    _chooseNewSyncSourceOpTime = ot;
    return _chooseNewSyncSourceResult;
}

void SyncSourceSelectorMock::blacklistSyncSource(const HostAndPort& host, Date_t until) {
    _lastBlacklistedSyncSource = host;
    _lastBlacklistExpiration = until;
}

void SyncSourceSelectorMock::setChooseNewSyncSourceHook_forTest(
    const ChooseNewSyncSourceHook& hook) {
    _chooseNewSyncSourceHook = hook;
}

bool SyncSourceSelectorMock::shouldChangeSyncSource(const HostAndPort&,
                                                    const rpc::ReplSetMetadata&,
                                                    const rpc::OplogQueryMetadata& oqMetadata) {
    return false;
}

void SyncSourceSelectorMock::setChooseNewSyncSourceResult_forTest(const HostAndPort& syncSource) {
    _chooseNewSyncSourceResult = syncSource;
}

OpTime SyncSourceSelectorMock::getChooseNewSyncSourceOpTime_forTest() const {
    return _chooseNewSyncSourceOpTime;
}

HostAndPort SyncSourceSelectorMock::getLastBlacklistedSyncSource_forTest() const {
    return _lastBlacklistedSyncSource;
}

Date_t SyncSourceSelectorMock::getLastBlacklistExpiration_forTest() const {
    return _lastBlacklistExpiration;
}

}  // namespace repl
}  // namespace mongo
